@@ -7,11 +7,11 @@ use std::{
 use anyhow::{bail, Context, Result};
 use clap::Args;
 use swc_common::SourceMap;
-use swc_ecma_minifier::option::MinifyOptions;
-use swc_ecma_transforms_base::fixer::fixer;
-use swc_ecma_visit::VisitMutWith;
 
-use crate::util::{minifier::get_esbuild_output, parse_js, print_js};
+use crate::util::{
+    minifier::{get_esbuild_output, get_minified},
+    print_js,
+};
 
 /// Opens vscode for diffing output of swc minifier and terser/esbuild
 #[derive(Debug, Args)]
@@ -21,35 +21,17 @@ pub struct CompareCommand {
 
 impl CompareCommand {
     pub fn run(self, cm: Arc<SourceMap>) -> Result<()> {
-        let fm = cm.load_file(&self.path).context("failed to load file")?;
-        let i = parse_js(fm)?;
-        let code_mangled = {
-            let mut minified_mangled = {
-                let m = i.module.clone();
-                swc_ecma_minifier::optimize(
-                    m,
-                    cm.clone(),
-                    None,
-                    None,
-                    &MinifyOptions {
-                        compress: Some(Default::default()),
-                        mangle: Some(Default::default()),
-                        ..Default::default()
-                    },
-                    &swc_ecma_minifier::option::ExtraOptions {
-                        unresolved_mark: i.unresolved_mark,
-                        top_level_mark: i.top_level_mark,
-                    },
-                )
-            };
-
-            minified_mangled.visit_mut_with(&mut fixer(None));
-
-            print_js(cm, &minified_mangled, true).context("failed to convert ast to code")?
-        };
+        let minified_mangled = get_minified(cm.clone(), &self.path, true, true)?;
+        let code_mangled = print_js(cm, &minified_mangled.module, true)
+            .context("failed to convert ast to code")?;
 
         let esbuild_mangled = get_esbuild_output(&self.path, true)?;
 
+        eprintln!("swc: {} bytes", code_mangled.as_bytes().len());
+        eprintln!(
+            "swc: {} bytes (newline stripped)",
+            code_mangled.replace("\\n", "_").as_bytes().len()
+        );
         std::fs::write("swc.output.js", code_mangled.as_bytes())
             .context("failed to write swc.output.js")?;
 
@@ -58,6 +40,7 @@ impl CompareCommand {
         std::fs::write("esbuild.output.js", esbuild_mangled.as_bytes())
             .context("failed to write swc.output.js")?;
 
+        eprintln!("swc: {} bytes", esbuild_mangled.as_bytes().len());
         make_pretty("esbuild.output.js".as_ref())?;
 
         {
